aboutsummaryrefslogtreecommitdiffstats
path: root/tests/misc_default_line_ending.rs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/misc_default_line_ending.rs')
-rw-r--r--tests/misc_default_line_ending.rs18
1 files changed, 9 insertions, 9 deletions
diff --git a/tests/misc_default_line_ending.rs b/tests/misc_default_line_ending.rs
index f839e2c..306b1bc 100644
--- a/tests/misc_default_line_ending.rs
+++ b/tests/misc_default_line_ending.rs
@@ -1,35 +1,35 @@
-extern crate micromark;
-use micromark::{micromark, micromark_with_options, CompileOptions, LineEnding, Options};
+extern crate markdown;
+use markdown::{to_html, to_html_with_options, CompileOptions, LineEnding, Options};
use pretty_assertions::assert_eq;
#[test]
fn default_line_ending() -> Result<(), String> {
assert_eq!(
- micromark("> a"),
+ to_html("> a"),
"<blockquote>\n<p>a</p>\n</blockquote>",
"should use `\\n` default"
);
assert_eq!(
- micromark("> a\n"),
+ to_html("> a\n"),
"<blockquote>\n<p>a</p>\n</blockquote>\n",
"should infer the first line ending (1)"
);
assert_eq!(
- micromark("> a\r"),
+ to_html("> a\r"),
"<blockquote>\r<p>a</p>\r</blockquote>\r",
"should infer the first line ending (2)"
);
assert_eq!(
- micromark("> a\r\n"),
+ to_html("> a\r\n"),
"<blockquote>\r\n<p>a</p>\r\n</blockquote>\r\n",
"should infer the first line ending (3)"
);
assert_eq!(
- micromark_with_options(
+ to_html_with_options(
"> a",
&Options {
compile: CompileOptions {
@@ -44,7 +44,7 @@ fn default_line_ending() -> Result<(), String> {
);
assert_eq!(
- micromark_with_options(
+ to_html_with_options(
"> a\n",
&Options {
compile: CompileOptions {
@@ -54,7 +54,7 @@ fn default_line_ending() -> Result<(), String> {
..Options::default()
}
)?,
// To do: is this a bug in `micromark.js` that it uses `\r` for earlier line endings?
// "<blockquote>\r<p>a</p>\r</blockquote>\n",
"<blockquote>\n<p>a</p>\n</blockquote>\n",
"should support the given line ending, even if line endings exist"
@@ -54,7 +54,7 @@ fn default_line_ending() -> Result<(), String> {
}
)?,
- // To do: is this a bug in `micromark.js` that it uses `\r` for earlier line endings?
+ // To do: is this a bug in `to_html.js` that it uses `\r` for earlier line endings?
// "<blockquote>\r<p>a</p>\r</blockquote>\n",
"<blockquote>\n<p>a</p>\n</blockquote>\n",